@@ -14,11 +14,15 @@
 #include "femonservice.h"
 #include "femontools.h"
 
-#if defined(APIVERSNUM) && APIVERSNUM < 10723
-#error "VDR-1.7.23 API version or greater is required!"
+#if defined(APIVERSNUM) && APIVERSNUM < 10727
+#error "VDR-1.7.27 API version or greater is required!"
 #endif
 
-static const char VERSION[]       = "1.7.12";
+#ifndef GITVERSION
+#define GITVERSION ""
+#endif
+
+static const char VERSION[]       = "1.7.17" GITVERSION;
 static const char DESCRIPTION[]   = trNOOP("DVB Signal Information Monitor (OSD)");
 static const char MAINMENUENTRY[] = trNOOP("Signal Information");
 
@@ -135,7 +139,7 @@ bool cPluginFemon::Service(const char *Id, void *Data)
         FemonService_v1_0 *data = (FemonService_v1_0*)Data;
         if (!cDevice::ActualDevice())
            return false;
-        cDvbDevice *dev = dynamic_cast<cDvbDevice*>(cDevice::ActualDevice());
+        cDvbDevice *dev = getDvbDevice(cDevice::ActualDevice());
         data->fe_name = getFrontendName(dev);
         data->fe_status = getFrontendStatus(dev);
         data->fe_snr = getSNR(dev);
@@ -194,9 +198,9 @@ const char **cPluginFemon::SVDRPHelpPages(void)
 
 cString cPluginFemon::SVDRPCommand(const char *Command, const char *Option, int &ReplyCode)
 {
-  cDvbDevice *dev = dynamic_cast<cDvbDevice*>(cDevice::ActualDevice());
+  cDvbDevice *dev = getDvbDevice(cDevice::ActualDevice());
   if (*Option && isnumber(Option)) {
-     cDvbDevice *dev2 = dynamic_cast<cDvbDevice*>(cDevice::GetDevice(strtol(Option, NULL, 10)));
+     cDvbDevice *dev2 = dynamic_cast<cDvbDevice*>(cDevice::GetDevice(int(strtol(Option, NULL, 10))));
      if (dev2)
         dev = dev2;
      }
@@ -311,6 +315,7 @@ cMenuFemonSetup::cMenuFemonSetup(void)
   themes[eFemonThemeEgalsTry]      = tr("EgalsTry");
   themes[eFemonThemeDuotone]       = tr("Duotone");
   themes[eFemonThemeSilverGreen]   = tr("SilverGreen");
+  themes[eFemonThemePearlHD]       = tr("PearlHD");
 
   data = femonConfig;
   Setup();
