@@ -24,6 +24,13 @@
 
 class cFemonOsd : public cOsdObject, public cThread, public cStatus {
 private:
+  enum eDeviceSourceType {
+    DEVICESOURCE_DVBAPI = 0,
+    DEVICESOURCE_IPTV,
+    DEVICESOURCE_PVRINPUT,
+    DEVICESOURCE_COUNT
+    };
+
   static cFemonOsd *pInstance;
 
   cOsd             *m_Osd;
@@ -36,6 +43,10 @@ private:
   cPlugin          *m_SvdrpPlugin;
   int               m_Number;
   int               m_OldNumber;
+  int               m_Quality;
+  bool              m_QualityValid;
+  int               m_Strength;
+  bool              m_StrengthValid;
   uint16_t          m_SNR;
   bool              m_SNRValid;
   uint16_t          m_Signal;
@@ -44,9 +55,11 @@ private:
   bool              m_BERValid;
   uint32_t          m_UNC;
   bool              m_UNCValid;
+  cString           m_FrontendName;
   fe_status_t       m_FrontendStatus;
   bool              m_FrontendStatusValid;
   dvb_frontend_info m_FrontendInfo;
+  eDeviceSourceType m_DeviceSource;
   int               m_DisplayMode;
   int               m_OsdWidth;
   int               m_OsdHeight;
@@ -67,7 +80,7 @@ protected:
   cFemonOsd(const cFemonOsd&);
   cFemonOsd& operator= (const cFemonOsd&);
   virtual void Action(void);
-  virtual void ChannelSwitch(const cDevice * device, int channelNumber);
+  virtual void ChannelSwitch(const cDevice *device, int channelNumber, bool liveView);
   virtual void SetAudioTrack(int Index, const char * const *Tracks);
 
 public:
